@@ -22,9 +22,10 @@
 #' function for the models.
 #'
 #' @keywords simple slopes moderation interaction regression
-#' @return A formatted dataframe of the simple slopes of the specified lm model,
-#'         with DV, levels of IV, degrees of freedom, regression coefficient, t-value,
-#'         p-value, and the effect size, the semi-partial correlation squared.
+#' @return A formatted dataframe of the simple slopes of the specified lm
+#'         model, with DV, levels of IV, degrees of freedom, regression
+#'         coefficient, t-value, p-value, and the effect size, the
+#'         semi-partial correlation squared.
 #' @export
 #' @examples
 #' # Make the basic table
@@ -107,7 +108,7 @@ nice_slopes <- function(data,
   })
   df.list <- lapply(models.list, function(x) x[["df.residual"]])
   ES.list <- lapply(models.list, function(x) {
-    lmSupport_modelEffectSizes(x, Print = FALSE)$Effects[-1, 4]
+    sr2(x)$sr2
   })
   stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
   stats.list <- lapply(stats.list, function(x) x[predictor, ])
@@ -127,7 +128,7 @@ nice_slopes <- function(data,
   })
   df.list <- lapply(models.list, function(x) x[["df.residual"]])
   ES.list <- lapply(models.list, function(x) {
-    lmSupport_modelEffectSizes(x, Print = FALSE)$Effects[-1, 4]
+    sr2(x)$sr2
   })
   stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
   stats.list <- lapply(stats.list, function(x) x[predictor, ])
@@ -148,7 +149,7 @@ nice_slopes <- function(data,
   })
   df.list <- lapply(models.list, function(x) x[["df.residual"]])
   ES.list <- lapply(models.list, function(x) {
-    lmSupport_modelEffectSizes(x, Print = FALSE)$Effects[-1, 4]
+    sr2(x)$sr2
   })
   stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
   stats.list <- lapply(stats.list, function(x) x[predictor, ])
@@ -204,7 +205,7 @@ nice_slopes <- function(data,
     })
     df.list <- lapply(models.list, function(x) x[["df.residual"]])
     ES.list <- lapply(models.list, function(x) {
-      lmSupport_modelEffectSizes(x, Print = FALSE)$Effects[-1, 4]
+      sr2(x)$sr2
     })
     stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
     stats.list <- lapply(stats.list, function(x) x[predictor, ])
@@ -224,7 +225,7 @@ nice_slopes <- function(data,
     })
     df.list <- lapply(models.list, function(x) x[["df.residual"]])
     ES.list <- lapply(models.list, function(x) {
-      lmSupport_modelEffectSizes(x, Print = FALSE)$Effects[-1, 4]
+      sr2(x)$sr2
     })
     stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
     stats.list <- lapply(stats.list, function(x) x[predictor, ])
@@ -245,7 +246,7 @@ nice_slopes <- function(data,
     })
     df.list <- lapply(models.list, function(x) x[["df.residual"]])
     ES.list <- lapply(models.list, function(x) {
-      lmSupport_modelEffectSizes(x, Print = FALSE)$Effects[-1, 4]
+      sr2(x)$sr2
     })
     stats.list <- mapply(cbind, df.list, sums.list, ES.list, SIMPLIFY = FALSE)
     stats.list <- lapply(stats.list, function(x) x[predictor, ])
