@@ -10,9 +10,9 @@
 #' for column names that should be italic but that are not picked
 #' up automatically by the function. Select with numerical range, e.g., 1:3.
 #' @param highlight Highlight rows with statistically significant
-#'  results? Requires a column named "p" containing p-values.
-#'  Can either accept logical (TRUE/FALSE) OR a numeric value for
-#'  a custom critical p-value threshold (e.g., 0.10 or 0.001).
+#' results? Requires a column named "p" containing p-values.
+#' Can either accept logical (TRUE/FALSE) OR a numeric value for
+#' a custom critical p-value threshold (e.g., 0.10 or 0.001).
 #' @param col.format.p Applies p-value formatting to columns
 #' that cannot be named "p" (for example for a data frame full
 #' of p-values, also because it is not possible to have more
@@ -21,6 +21,8 @@
 #' that cannot be named "r" (for example for a data frame full
 #' of r-values, also because it is not possible to have more
 #' than one column named "r"). Select with numerical range, e.g., 1:3.
+#' @param col.format.ci Applies 95% confidence interval formatting
+#' to selected columns (e.g., when reporting more than one interval).
 #' @param format.custom Applies custom formatting to columns
 #' selected via the `col.format.custom` argument. This is useful
 #' if one wants custom formatting other than for p- or r-values.
@@ -41,7 +43,8 @@
 #' version of the tables made by the `report` package.
 #' @param title Optional, to add a table header, if desired.
 #' @param footnote Optional, to add a table footnote (or more), if desired.
-#' @param separate.header Logical, whether to separate headers based on name delimiters (i.e., periods ".").
+#' @param separate.header Logical, whether to separate headers based
+#'                        on name delimiters (i.e., periods ".").
 #'
 #' @keywords APA style table
 #' @return An APA-formatted table of class "flextable" (and "nice_table").
@@ -119,6 +122,7 @@
 #'
 #' @importFrom dplyr mutate %>% select matches
 #' case_when relocate across contains select_if any_of
+#' last_col
 #' @importFrom flextable "flextable" hline_top hline_bottom
 #' fontsize font align set_table_properties italic
 #' set_formatter colformat_double compose bold bg
@@ -137,6 +141,7 @@ nice_table <- function(data,
                        italics,
                        col.format.p,
                        col.format.r,
+                       col.format.ci,
                        format.custom,
                        col.format.custom,
                        width = 1,
@@ -347,13 +352,65 @@ nice_table <- function(data,
   #   _________________________________
   #   Formatting                   ####
 
+  if(!missing(separate.header)) {
+    filtered.names <- grep("[.]", names(dataframe), value = TRUE)
+    sh.pattern <- lapply(filtered.names, function(x) {
+      gsub("[^\\.]*$", "", x)
+    }) %>%
+      unlist %>%
+      unique
+    unique.pattern <- length(sh.pattern)
+  }
+
+  if (!missing(col.format.ci)) {
+    if(!methods::is(col.format.ci, "list")) {
+      col.format.ci <- list(col.format.ci)
+    }
+    for (i in col.format.ci) {
+      ci.name <- paste0(sh.pattern[i], "95% CI")
+      # ci.pattern <- gsub("\\..*", ".", i)[1]
+      # ci.name <- paste0(ci.pattern, "95% CI")
+      dataframe <- format_CI(
+        dataframe, i, col.name =
+          ci.name) %>%
+        relocate(all_of(ci.name), .after = select(
+          ., contains(sh.pattern), -last_col()) %>%
+            select(last_col()) %>% names)
+    }
+  }
+
   if ("CI_lower" %in% names(dataframe) & "CI_upper" %in% names(dataframe)) {
     dataframe <- format_CI(dataframe)
   }
+
+  if(!missing(separate.header)) {
+    CI_lower.sh <- paste0(sh.pattern, rep(
+      "CI_lower", each = unique.pattern))
+    CI_upper.sh <- paste0(sh.pattern, rep(
+      "CI_upper", each = unique.pattern))
+    CI.df <- data.frame(CI_lower.sh, CI_upper.sh)
+    names(CI.df) <- NULL
+
+    if (any(unlist(CI.df) %in% names(dataframe))) {
+
+      for (i in seq(nrow(CI.df))) {
+        ci.name <- paste0(sh.pattern[i], "95% CI")
+        dataframe <- format_CI(
+          dataframe,
+          CI_low_high = unlist(CI.df[i, ]),
+          col.name = ci.name) %>%
+          relocate(all_of(ci.name), .after = select(
+            ., contains(sh.pattern[i]), -last_col()) %>%
+              select(last_col()) %>% names)
+      }
+    }
+  }
+
   dataframe %>%
     mutate(across(contains("95% CI"), ~ ifelse(
       .x == "[ NA,  NA]", "", .x
     ))) -> dataframe
+
   if (highlight == TRUE) {
     dataframe %>%
       mutate(signif = ifelse(p < .05, TRUE, FALSE)) -> dataframe
@@ -366,14 +423,14 @@ nice_table <- function(data,
   #   __________________________________
   #   Flextable                     ####
 
-  dataframe %>%
+  table <- dataframe %>%
     {
       if (highlight == TRUE || is.numeric(highlight)) {
         flextable(., col_keys = names(dataframe)[-length(dataframe)])
       } else {
         flextable(.)
       }
-    } -> table
+    }
 
   nice.borders <- list("width" = 0.5, color = "black", style = "solid")
   table %>%
@@ -388,9 +445,9 @@ nice_table <- function(data,
   if (!missing(width)) {
     table %>%
       set_table_properties(layout = "autofit", width = width) -> table
-   } else {
+  } else {
     table %>%
-     set_table_properties(layout = "autofit") -> table
+      set_table_properties(layout = "autofit") -> table
   }
 
   if (!missing(footnote)) {
@@ -410,9 +467,10 @@ nice_table <- function(data,
     }
   }
 
+  # Separate headers
   if (!missing(separate.header)) {
     table <- table %>%
-      separate_header("span-top")
+      separate_header("span-top", split = "[.]")
   }
 
   table <- table %>%
@@ -424,6 +482,7 @@ nice_table <- function(data,
 
   ##  ....................................
   ##  Special cases                  ####
+  # Fix header with italics
   if (!missing(italics) & missing(separate.header)) {
     table %>%
       italic(j = italics, part = "header") -> table
@@ -433,15 +492,33 @@ nice_table <- function(data,
     table %>%
       italic(j = italics, i = level.number, part = "header") -> table
   }
-  if ("df" %in% names(dataframe)) {
-    df.digits <- ifelse(any(dataframe$df %% 1 == 0), 0, 2)
-    table %>%
-      format_flex(j = "df", digits = df.digits) -> table
+
+  # Degrees of freedom
+  cols.df <- "df"
+  if(!missing(separate.header)) {
+    cols.df.sh <- paste0(sh.pattern, rep(
+      cols.df, each = unique.pattern))
+    cols.df <- c(cols.df, cols.df.sh)
+  }
+
+  for (i in cols.df) {
+    if (i %in% names(dataframe)) {
+      df.digits <- ifelse(any(dataframe[i] %% 1 == 0), 0, 2)
+      table %>%
+        format_flex(j = i, digits = df.digits) -> table
+    }
   }
 
   ##  .....................................
   ##  2-digit columns                 ####
+
   cols.2digits <- c("t", "SE", "SD", "F", "b", "M", "W", "d", "Mu", "S")
+  if(!missing(separate.header)) {
+    cols.2digits.sh <- paste0(sh.pattern, rep(
+      cols.2digits, each = unique.pattern))
+    cols.2digits <- c(cols.2digits, cols.2digits.sh)
+  }
+
   for (i in cols.2digits) {
     if (i %in% names(dataframe)) {
       table %>%
@@ -452,6 +529,12 @@ nice_table <- function(data,
   ##  .....................................
   ##  0-digit columns                 ####
   cols.0digits <- c("N", "n", "z")
+  if(!missing(separate.header)) {
+    cols.0digits.sh <- paste0(sh.pattern, rep(
+      cols.0digits, each = unique.pattern))
+    cols.0digits <- c(cols.0digits, cols.0digits.sh)
+  }
+
   for (i in cols.0digits) {
     if (i %in% names(dataframe)) {
       table %>%
@@ -465,6 +548,18 @@ nice_table <- function(data,
     col = c("r", "p"),
     fun = c("format_r", "format_p")
   )
+
+  if(!missing(separate.header)) {
+    cols.sh <- paste0(sh.pattern, rep(
+      compose.table0$col, each = unique.pattern))
+    table0.sh <- data.frame(
+      col = cols.sh,
+      fun = rep(compose.table0$fun, each =
+                  length(cols.sh) / length(compose.table0$fun))
+    )
+    compose.table0 <- rbind(compose.table0, table0.sh)
+  }
+
   for (i in seq(nrow(compose.table0))) {
     if (compose.table0[i, "col"] %in% names(dataframe)) {
       table %>%
@@ -519,6 +614,18 @@ nice_table <- function(data,
     col = c("R2", "sr2"),
     value = c('as_i("R"), as_sup("2")', 'as_i("sr"), as_sup("2")')
   )
+
+  if(!missing(separate.header)) {
+    cols.sh <- paste0(sh.pattern, rep(
+      compose.table2$col, each = unique.pattern))
+    table2.sh <- data.frame(
+      col = cols.sh,
+      value = rep(compose.table2$value, each =
+                  length(cols.sh) / length(compose.table2$value))
+    )
+    compose.table2 <- rbind(compose.table2, table2.sh)
+  }
+
   for (i in seq(nrow(compose.table2))) {
     if (compose.table2[i, "col"] %in% names(dataframe)) {
       table %>%
@@ -545,13 +652,22 @@ nice_table <- function(data,
   #   _____________________________________________
   #   Extra features                           ####
 
+  dont.change0 <- c("p", "r", "t", "SE", "SD", "F", "df", "b",
+                    "M", "N", "n", "Z", "z", "W", "R2", "sr2")
+  dont.change <- paste0("^", dont.change0, "$", collapse = "|")
+
+  if(!missing(separate.header)) {
+    dont.change.sh <- paste0(sh.pattern, rep(
+      dont.change0, each = unique.pattern))
+    dont.change.sh <- paste0("^", dont.change.sh, "$", collapse = "|")
+    dont.change <- paste0(dont.change, "|", dont.change.sh)
+  }
+
   table %>%
     colformat_double(
       j = (select(dataframe, where(is.numeric)) %>%
-             select(-matches("^p$|^r$|^t$|^SE$|^SD$|^F$|^df$|
-                            ^b$|^M$|^N$|^n$|^Z$|^z$|^W$|^R2$|
-                             ^sr2$",
-                             ignore.case = FALSE
+             select(-matches(dont.change,
+               ignore.case = FALSE
              )) %>% names()),
       big.mark = ",", digits = 2
     ) -> table
@@ -582,8 +698,8 @@ nice_table <- function(data,
     eval(parse(text = rExpression))
   }
 
-  #   ____________________________________________________________________________
-  #   Final touch up (title)                                                  ####
+  #   ___________________________
+  #   Final touch up (title) ####
 
   if (!missing(title)) {
     invisible.borders <- fp_border_default("width" = 0)
@@ -639,7 +755,7 @@ format_flex <- function(table, j, digits = 2, value, fun) {
     rExpression <- paste0("as_paragraph(", value, ")")
     table %>%
       compose(
-        i = 1, j = j, part = "header",
+        i = NULL, j = j, part = "header",
         value = eval(parse(text = rExpression))
       ) -> table
   }
