@@ -1,11 +1,3 @@
-#' @importFrom ggplot2 ggsave
-#' @export
-ggplot2::ggsave
-
-#' @importFrom ggplot2 waiver
-#' @export
-ggplot2::waiver
-
 #' @importFrom flextable save_as_docx
 #' @export
 flextable::save_as_docx
